@@ -1,6 +1,7 @@
 import argparse
 
 import annofabcli
+import annofabcli.annotation.change_annotation_attributes
 import annofabcli.annotation.delete_annotation
 import annofabcli.annotation.dump_annotation
 import annofabcli.annotation.import_annotation
@@ -14,6 +15,7 @@ def parse_args(parser: argparse.ArgumentParser):
     subparsers = parser.add_subparsers(dest="subcommand_name")
 
     # サブコマンドの定義
+    annofabcli.annotation.change_annotation_attributes.add_parser(subparsers)
     annofabcli.annotation.delete_annotation.add_parser(subparsers)
     annofabcli.annotation.dump_annotation.add_parser(subparsers)
     annofabcli.annotation.import_annotation.add_parser(subparsers)
